==> resh-5.3.0.6-py3-none-any.whl: resh/protocols/can_utils/modbusi_packet.py <==
from typing import Union

from dali.command import from_frame
from dali.frame import ForwardFrame

from resh.protocols.payloads import Payload
from . import CLASS_MODBUS, can_packet
from ..payloads import dali as dali_payload


class ModbusSend(can_packet.CanSend):
    PLL = 6

    def __init__(self, module_address, channel, end_frame):
        super(ModbusSend, self).__init__(CLASS_MODBUS, module_address, end_frame, cmd=0)
        self._channel = channel
        self._last_byte = 0
        self.dump = None

    def check_commit(self, dump): pass

    @property
    def committed(self): return True

    def on_response(self, dump):
        if isinstance(dump, ModbusDump) and dump.channel == self.channel:
            if self.dump is None:
                self.dump = dump.data
            else:
                self.dump += dump.data

            if dump.has_next is False:
                self.stop_answer_timer()
                return self.dump

    def send(self, need_answer):
        result = super(ModbusSend, self).send(not self.has_next and need_answer)
        if self.has_next:
            self._last_byte += self.PLL
            return self.send(need_answer)

        return result

    @property
    def frame(self):
        b1 = self.channel - 1
        if self.has_next:
            b1 = b1 | 0x04
        return bytes([self.module_type, b1]) + self.end_frame[self._last_byte:self._last_byte + self.PLL]

    @property
    def payload(self):
        return generate_payload(self)

    @property
    def channel(self):
        return self._channel

    @property
    def data(self) -> bytearray:
        return self.end_frame

    @staticmethod
    def channel_from_frame(frame: bytearray) -> int:
        return 8 - bin(frame[2])[2:].rjust(8, '0').rindex('1')

    @property
    def has_next(self) -> bool:
        return self._last_byte + self.PLL < len(self.end_frame)


class ModbusDump(can_packet.CanDump):
    @property
    def channel(self):
        return (self.frame[1] & 0x3) + 1

    @property
    def address(self):
        return self.frame[2]

    @property
    def data(self):
        return self.frame[2:]

    @property
    def payload(self):
        return generate_payload(self)

    @property
    def has_next(self) -> bool:
        return self.frame[1] & 0x04 == 0x04


query_class = None


def generate_payload(dump: Union[ModbusDump, ModbusSend]):
    frame = dump.data
    size = len(frame)

    global query_class

    if size < 2:
        return dali_payload.DaliResponse(query_class, dump)
    elif size == 2:
        cmd = from_frame(ForwardFrame(16, frame))
        if cmd.is_query and isinstance(dump, ModbusDump):
            query_class = cmd
        return dali_payload.DaliCommand(dump, cmd)
    elif size == 3:
        if frame[0] & 1 == 0:
            return dali_payload.Dali2Event(dump)
        else:
            cmd = from_frame(ForwardFrame(24, frame))
            if cmd.is_query and isinstance(dump, ModbusDump):
                query_class = cmd
            return dali_payload.Dali2Command(dump, cmd)

    return Payload(dump)

==> resh-5.5.0.95-py3-none-any.whl: resh/protocols/can_utils/modbusi_packet.py <==
from typing import Union

from dali.command import from_frame
from dali.frame import ForwardFrame

from resh.protocols.payloads import Payload
from . import can_packet
from .rapida.const import CLASS_MODBUS
from ..payloads import dali as dali_payload


class ModbusSend(can_packet.CanSend):
    PLL = 6

    def __init__(self, module_address, channel, ext_mode, end_frame):
        super(ModbusSend, self).__init__(CLASS_MODBUS, module_address, ext_mode, 0, end_frame, cmd=0)
        self._channel = channel
        self._last_byte = 0
        self.dump = None

    def check_commit(self, dump): pass

    @property
    def committed(self): return True

    def on_response(self, dump):
        if isinstance(dump, ModbusDump) and dump.channel == self.channel:
            if self.dump is None:
                self.dump = dump.data
            else:
                self.dump += dump.data

            if dump.has_next is False:
                self.stop_answer_timer()
                return self.dump

    def send(self, need_answer):
        result = super(ModbusSend, self).send(not self.has_next and need_answer)
        if self.has_next:
            self._last_byte += self.PLL
            return self.send(need_answer)

        return result

    @property
    def frame(self):
        b1 = self.channel - 1
        if self.has_next:
            b1 = b1 | 0x04
        return bytes([self.module_type, b1]) + self.end_frame[self._last_byte:self._last_byte + self.PLL]

    @property
    def payload(self):
        return generate_payload(self)

    @property
    def channel(self):
        return self._channel

    @property
    def data(self) -> bytearray:
        return self.end_frame

    @staticmethod
    def channel_from_frame(frame: bytearray) -> int:
        return 8 - bin(frame[2])[2:].rjust(8, '0').rindex('1')

    @property
    def has_next(self) -> bool:
        return self._last_byte + self.PLL < len(self.end_frame)


class ModbusDump(can_packet.CanDump):
    @property
    def channel(self):
        return (self.frame[1] & 0x3) + 1

    @property
    def address(self):
        return self.frame[2]

    @property
    def data(self):
        return self.frame[2:]

    @property
    def payload(self):
        return generate_payload(self)

    @property
    def has_next(self) -> bool:
        return self.frame[1] & 0x04 == 0x04


query_class = None


def generate_payload(dump: Union[ModbusDump, ModbusSend]):
    frame = dump.data
    size = len(frame)

    global query_class

    if size < 2:
        return dali_payload.DaliResponse(query_class, dump)
    elif size == 2:
        cmd = from_frame(ForwardFrame(16, frame))
        if cmd.is_query and isinstance(dump, ModbusDump):
            query_class = cmd
        return dali_payload.DaliCommand(dump, cmd)
    elif size == 3:
        if frame[0] & 1 == 0:
            return dali_payload.Dali2Event(dump)
        else:
            cmd = from_frame(ForwardFrame(24, frame))
            if cmd.is_query and isinstance(dump, ModbusDump):
                query_class = cmd
            return dali_payload.Dali2Command(dump, cmd)

    return Payload(dump)
